@@ -2,35 +2,38 @@ package Test::Bifcode;
 use bytes;
 use strict;
 use warnings;
-
 use utf8;
-use Bifcode qw/decode_bifcode encode_bifcode force_bifcode diff_bifcode/;
+use boolean;
+use Bifcode::V2
+  qw/decode_bifcodeV2 encode_bifcodeV2 force_bifcodeV2 diff_bifcodeV2/;
 use Carp;
 use Exporter::Tidy default => [
-    qw($bytes $BYTES
-      $utf8 $UTF8
+    qw($bytes $BYTES $BYTES_KEY
+      $utf8 $UTF8 $UTF8_KEY
       $data1 $DATA1
       $data2 $DATA2
       enc_ok
-      enc_error_ok
-      decod_ok
-      error_ok)
+      encode_err
+      decode_ok
+      decode_err)
 ];
-use Test::More 0.88;    # for done_testing
+use Test2::V0;
 
 our $utf8 = "\x{100}\x{df}";
 
 #'ฉันกินกระจกได้ แต่มันไม่ทำให้ฉันเจ็บ';
 utf8::encode( my $utf8_bytes = $utf8 );
 my $utf8_length = bytes::length($utf8_bytes);
-our $UTF8 = 'U' . $utf8_length . ':' . $utf8_bytes . ',';
+our $UTF8     = 'u' . $utf8_length . '.' . $utf8_bytes . ',';
+our $UTF8_KEY = 'u' . $utf8_length . '.' . $utf8_bytes . ':';
 
 our $bytes = pack( 's<', 255 );
 my $bytes_length = bytes::length($bytes);
-our $BYTES = 'B' . $bytes_length . ':' . $bytes . ',';
+our $BYTES     = 'b' . $bytes_length . '.' . $bytes . ',';
+our $BYTES_KEY = 'b' . $bytes_length . '.' . $bytes . ':';
 
 our $data1 = {
-    bools   => [ $Bifcode::FALSE, $Bifcode::TRUE, ],
+    bools   => [ false, true, ],
     bytes   => \$bytes,
     integer => 25,
     float   => -1.25e-9,
@@ -39,15 +42,15 @@ our $data1 = {
 };
 
 our $DATA1 = '{'
-  . ( 'U5:bools,' . '[01]' )
-  . ( 'U5:bytes,' . $BYTES )
-  . ( 'U5:float,' . 'F-1.25e-9,' )
-  . ( 'U7:integer,' . 'I25,' )
-  . ( 'U5:undef,' . '~' )
-  . ( 'U4:utf8,' . $UTF8 ) . '}';
+  . ( 'u5.bools:' . '[f,t,]' )
+  . ( 'u5.bytes:' . $BYTES )
+  . ( 'u5.float:' . 'r-1.25e-9,' )
+  . ( 'u7.integer:' . 'i25,' )
+  . ( 'u5.undef:' . '~,' )
+  . ( 'u4.utf8,' . $UTF8 ) . '}';
 
 our $data2 = {
-    bools   => [ $Bifcode::FALSE, $Bifcode::TRUE, ],
+    bools   => [ false, true, ],
     bytes   => \$bytes,
     integer => 24,
     float   => 1.25e-9,
@@ -56,29 +59,28 @@ our $data2 = {
 };
 
 our $DATA2 = '{'
-  . ( 'U5:bools,' . '[01]' )
-  . ( 'U5:bytes,' . $BYTES )
-  . ( 'U5:float,' . 'F1.25e-9,' )
-  . ( 'U7:integer,' . 'I24,' )
-  . ( 'U5:undef,' . '~' )
-  . ( 'U4:utf8,' . $UTF8 ) . '}';
+  . ( 'u5.bools:' . '[f,t,]' )
+  . ( 'u5.bytes:' . $BYTES )
+  . ( 'u5.float:' . 'r1.25e-9,' )
+  . ( 'u7.integer:' . 'i24,' )
+  . ( 'u5.undef:' . '~,' )
+  . ( 'u4.utf8:' . $UTF8 ) . '}';
 
 sub enc_ok {
     croak 'usage: enc_ok($1,$2)'
       unless 2 == @_;
     my ( $thawed, $frozen ) = @_;
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-    my $diff = diff_bifcode( encode_bifcode($thawed), $frozen );
+    my $diff = diff_bifcodeV2( encode_bifcodeV2($thawed), $frozen );
     length($diff)
       ? ok 0, "encode $frozen:\n$diff"
       : ok 1, "encode $frozen";
 }
 
-sub enc_error_ok {
+sub encode_err {
     my ( $data, $error, $kind_of_brokenness ) = @_;
+    $kind_of_brokenness // Carp::croak 'encode_err needs $kind_of_brokenness';
     local $@;
-    eval { encode_bifcode $data };
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    eval { encode_bifcodeV2 $data };
     my $have = ref $@;
     my $want = 'Bifcode::Error::' . $error;
     my $ok   = $have eq $want;
@@ -91,22 +93,20 @@ sub un {
     local $, = ', ';
     my $frozen_str = $frozen // '*undef*';
     return 'ARRAY' eq ref $frozen
-      ? ( "decode [@$frozen_str]", decode_bifcode @$frozen )
-      : ( "decode '$frozen_str'", decode_bifcode $frozen );
+      ? ( "decode [@$frozen_str]", decode_bifcodeV2 @$frozen )
+      : ( "decode '$frozen_str'", decode_bifcodeV2 $frozen );
 }
 
-sub decod_ok {
+sub decode_ok {
     my ( $frozen,   $thawed ) = @_;
     my ( $testname, $result ) = un $frozen;
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
-    is_deeply $result, $thawed, $testname;
+    is $result, $thawed, $testname;
 }
 
-sub error_ok {
+sub decode_err {
     my ( $frozen, $error, $kind_of_brokenness ) = @_;
     local $@;
     eval { un $frozen };
-    local $Test::Builder::Level = $Test::Builder::Level + 1;
     my $have = ref $@;
     my $want = 'Bifcode::Error::' . $error;
     my $ok   = $have eq $want;
